'use strict';

var clientEks = require('@aws-sdk/client-eks');
var integrationAwsNode = require('@backstage/integration-aws-node');
var defaultTransformers = require('../lib/defaultTransformers.cjs.js');

class AwsEKSClusterProcessor {
  credentialsFactory;
  credentialsManager;
  clusterEntityTransformer;
  static fromConfig(configRoot, options) {
    const awsCredentialsManager = integrationAwsNode.DefaultAwsCredentialsManager.fromConfig(configRoot);
    return new AwsEKSClusterProcessor({
      credentialsManager: awsCredentialsManager,
      ...options
    });
  }
  constructor(options) {
    this.credentialsFactory = options.credentialsFactory;
    this.credentialsManager = options.credentialsManager;
    this.clusterEntityTransformer = options.clusterEntityTransformer || defaultTransformers.defaultEksClusterEntityTransformer;
  }
  getProcessorName() {
    return "aws-eks";
  }
  async readLocation(location, _optional, emit) {
    if (location.type !== "aws-eks") {
      return false;
    }
    const [accountId, region] = location.target.split("/");
    if (!accountId || !region) {
      throw new Error(
        "AWS EKS location specified without account or region information"
      );
    }
    let credentials;
    if (this.credentialsFactory) {
      credentials = await this.credentialsFactory(accountId);
    }
    let providerFunction;
    if (this.credentialsManager) {
      const credentialsProvider = await this.credentialsManager.getCredentialProvider({ accountId });
      providerFunction = () => credentialsProvider.sdkCredentialProvider;
    }
    const eksClient = new clientEks.EKS({
      customUserAgent: "backstage-aws-catalog-eks-cluster-processor",
      credentials,
      credentialDefaultProvider: providerFunction,
      region
    });
    const clusters = await eksClient.listClusters({});
    if (clusters.clusters === void 0) {
      return true;
    }
    const results = clusters.clusters.map((cluster) => eksClient.describeCluster({ name: cluster })).map(async (describedClusterPromise) => {
      const describedCluster = await describedClusterPromise;
      if (describedCluster.cluster) {
        const entity = await this.clusterEntityTransformer(
          describedCluster.cluster,
          accountId
        );
        emit({
          type: "entity",
          entity,
          location
        });
      }
    });
    await Promise.all(results);
    return true;
  }
}

exports.AwsEKSClusterProcessor = AwsEKSClusterProcessor;
//# sourceMappingURL=AwsEKSClusterProcessor.cjs.js.map
